/*
 * Simulator of microcontrollers (cmdset.cc)
 *
 * Copyright (C) 1999,99 Drotos Daniel, Talker Bt.
 * 
 * To contact author send email to drdani@mazsola.iit.uni-miskolc.hu
 *
 */

/* This file is part of microcontroller simulator: ucsim.

UCSIM is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

UCSIM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with UCSIM; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
/*@1@*/

#include "ddconfig.h"

// sim
#include "simcl.h"

// local
#include "cmdsetcl.h"


/*
 * Command: conf
 *----------------------------------------------------------------------------
 */


int
cl_conf_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  int i;

  con->printf("ucsim version %s\n", VERSIONSTR);
  con->printf("Type of microcontroller: %s\n", sim->uc->id_string());
  con->printf("Controller has %d hardware element(s).\n",
	      sim->uc->hws->count);
  for (i= 0; i < sim->uc->hws->count; i++)
    {
      class cl_hw *hw= (class cl_hw *)(sim->uc->hws->at(i));
      con->printf("  %s\n", hw->id_string());
    }
  con->printf("Memories:\n");
  for (i= MEM_ROM; i < MEM_TYPES; i++)
    {
      class cl_mem *mem= (class cl_mem *)(sim->uc->mems->at(i));
      con->printf("  %s ", mem->id_string());
      if (mem)
	con->printf("size= 0x%06x %d\n", mem->size, mem->size);
      else
	con->printf("n/a\n");
    }
  return(0);
}


/*
 * Command: state
 *----------------------------------------------------------------------------
 */


int
cl_state_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  con->printf("sim state= %d PC= %06x\n", sim->state, sim->uc->PC);
  return(0);
}


/*
 * Command: run
 *----------------------------------------------------------------------------
 */


int
cl_run_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  sim->start(con);
  return(0);
}


/*
 * Command: step
 *----------------------------------------------------------------------------
 */


int
cl_step_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  sim->uc->do_inst(1);
  return(0);
}


/*
 * Command: reset
 *----------------------------------------------------------------------------
 */


int
cl_reset_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  sim->uc->reset();
  return(0);
}


/*
 * Command: dump
 *----------------------------------------------------------------------------
 */

int
cl_dump_cmd::work(class cl_cmdline *cmdline, class cl_console *con)
{
  (sim->uc->mem(MEM_ROM))->dump(-1, 64, 8, con);
  return(0);
}


/*
 * Command: quit
 *----------------------------------------------------------------------------
 */

int
cl_quit_cmd::work(class cl_cmdline */*cmdline*/, class cl_console */*con*/)
{
  return(1);
}


/* End of cmdset.cc */
